@@ -1,9 +1,24 @@
 #!/bin/sh -e
 
 echo Running meson-dist-script
+export CARGO="${CARGO:-$_defaultCARGO}"
+
 echo PWD=$(pwd)
 echo MESON_SOURCE_ROOT=$MESON_SOURCE_ROOT
 echo MESON_PROJECT_DIST_ROOT=$MESON_PROJECT_DIST_ROOT
+echo CARGO=$CARGO
+
+if [ -z "${BUILDER_VERSION}" ]; then
+    echo "BUILDER_VERSION is not set" >&2
+    exit 1
+fi
+
+if [ -z "${CARGO}" ]; then
+    echo PATH=$PATH
+    ls -l /usr/bin/cargo
+    export CARGO=/usr/bin/cargo
+    #exit 1
+fi
 
 cd "$MESON_PROJECT_DIST_ROOT"
 
@@ -25,6 +40,8 @@ echo Running autoreconf -vi so distfile is still usable for autotools building
 # Run autoconf for people using autotools to build, this creates a configure sc
 autoreconf -vi
 rm -rf "$MESON_PROJECT_DIST_ROOT"/autom4te.cache
+echo Updating the version of the Rust library to ${BUILDER_VERSION}
+"$MESON_SOURCE_ROOT"/../../builder-support/helpers/update-rust-library-version.py "$MESON_PROJECT_DIST_ROOT"/rec-rust-lib/rust/Cargo.toml recrust ${BUILDER_VERSION}
 
 cd "$MESON_PROJECT_BUILD_ROOT"
 
@@ -40,6 +57,18 @@ cp -vp pubsuffix.cc "$MESON_PROJECT_DIST_ROOT"
 meson compile rec-rust-sources
 cp -vp "$MESON_SOURCE_ROOT"/rec-rust-lib/rust/src/lib.rs "$MESON_PROJECT_DIST_ROOT"/rec-rust-lib/rust/src/
 
+echo Updating the version of the Rust library to ${BUILDER_VERSION}
+"$MESON_SOURCE_ROOT"/../../builder-support/helpers/update-rust-library-version.py "$MESON_PROJECT_DIST_ROOT"/rec-rust-lib/rust/Cargo.toml recrust ${BUILDER_VERSION}
+# Update the version of the Rust library in Cargo.lock as well,
+# This needs to be done AFTER the sources of the Rust library have been generated
+# Unfortunately we cannot use --offline because for some reason cargo-update wants
+# to check all dependencies even though we are telling it exactly what to update
+cd "$MESON_PROJECT_DIST_ROOT"/rec-rust-lib/rust/
+ls -l /usr/bin/cargo
+echo $CARGO update --verbose --precise ${BUILDER_VERSION} recrust
+$CARGO update --verbose --precise ${BUILDER_VERSION} recrust
+cd "$MESON_PROJECT_BUILD_ROOT"
+
 # Generate man pages
 meson compile man-pages
 cp -vp *.1 "$MESON_PROJECT_DIST_ROOT"
